@@ -1,17 +1,17 @@
 use futures::future::TryFutureExt;
 
-use std::{self, cell::RefCell, collections::HashMap, fmt, ops::Deref, sync::Arc};
+use std::{self, cell::RefCell, collections::HashMap, fmt, ops::Deref, sync::Arc, sync::RwLock};
 
 use diesel::{
     connection::TransactionManager,
     delete,
     dsl::max,
-    expression::sql_literal::sql,
+    dsl::sql,
     mysql::MysqlConnection,
     r2d2::{ConnectionManager, PooledConnection},
     sql_query,
     sql_types::{BigInt, Integer, Nullable, Text},
-    Connection, ExpressionMethods, GroupByDsl, OptionalExtension, QueryDsl, RunQueryDsl,
+    Connection, ExpressionMethods, OptionalExtension, QueryDsl, RunQueryDsl,
 };
 #[cfg(debug_assertions)]
 use diesel_logger::LoggingConnection;
@@ -32,6 +32,10 @@ use super::{
 };
 
 type Conn = PooledConnection<ConnectionManager<MysqlConnection>>;
+#[cfg(not(debug_assertions))]
+type InternalConn = Conn;
+#[cfg(debug_assertions)]
+type InternalConn = LoggingConnection<Conn>; // display SQL when RUST_LOG="diesel_logger=trace"
 
 // this is the max number of records we will return.
 static DEFAULT_LIMIT: u32 = DEFAULT_MAX_TOTAL_RECORDS;
@@ -92,10 +96,7 @@ pub struct MysqlDb {
 unsafe impl Send for MysqlDb {}
 
 pub struct MysqlDbInner {
-    #[cfg(not(debug_assertions))]
-    pub(super) conn: Conn,
-    #[cfg(debug_assertions)]
-    pub(super) conn: LoggingConnection<Conn>, // display SQL when RUST_LOG="diesel_logger=trace"
+    pub(super) conn: RwLock<InternalConn>,
 
     session: RefCell<MysqlDbSession>,
 }
@@ -124,9 +125,9 @@ impl MysqlDb {
     ) -> Self {
         let inner = MysqlDbInner {
             #[cfg(not(debug_assertions))]
-            conn,
+            conn: RwLock::new(conn),
             #[cfg(debug_assertions)]
-            conn: LoggingConnection::new(conn),
+            conn: RwLock::new(LoggingConnection::new(conn)),
             session: RefCell::new(Default::default()),
         };
         // https://github.com/mozilla-services/syncstorage-rs/issues/1480
@@ -149,7 +150,7 @@ impl MysqlDb {
     /// In theory it would be possible to use serializable transactions rather
     /// than explicit locking, but our ops team have expressed concerns about
     /// the efficiency of that approach at scale.
-    fn lock_for_read_sync(&self, params: params::LockCollection) -> DbResult<()> {
+    fn lock_for_read_sync(&mut self, params: params::LockCollection) -> DbResult<()> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection).or_else(|e| {
             if e.is_collection_not_found() {
@@ -178,7 +179,7 @@ impl MysqlDb {
             .filter(user_collections::user_id.eq(user_id))
             .filter(user_collections::collection_id.eq(collection_id))
             .for_share()
-            .first(&self.conn)
+            .first(&mut *self.conn.write()?)
             .optional()?;
         if let Some(modified) = modified {
             let modified = SyncTimestamp::from_i64(modified)?;
@@ -195,7 +196,7 @@ impl MysqlDb {
         Ok(())
     }
 
-    fn lock_for_write_sync(&self, params: params::LockCollection) -> DbResult<()> {
+    fn lock_for_write_sync(&mut self, params: params::LockCollection) -> DbResult<()> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_or_create_collection_id(&params.collection)?;
         if let Some(CollectionLock::Read) = self
@@ -216,7 +217,7 @@ impl MysqlDb {
             .filter(user_collections::user_id.eq(user_id))
             .filter(user_collections::collection_id.eq(collection_id))
             .for_update()
-            .first(&self.conn)
+            .first(&mut *self.conn.write()?)
             .optional()?;
         if let Some(modified) = modified {
             let modified = SyncTimestamp::from_i64(modified)?;
@@ -236,10 +237,10 @@ impl MysqlDb {
         Ok(())
     }
 
-    pub(super) fn begin(&self, for_write: bool) -> DbResult<()> {
-        self.conn
-            .transaction_manager()
-            .begin_transaction(&self.conn)?;
+    pub(super) fn begin(&mut self, for_write: bool) -> DbResult<()> {
+        <InternalConn as Connection>::TransactionManager::begin_transaction(
+            &mut *self.conn.write()?,
+        )?;
         self.session.borrow_mut().in_transaction = true;
         if for_write {
             self.session.borrow_mut().in_write_transaction = true;
@@ -247,29 +248,29 @@ impl MysqlDb {
         Ok(())
     }
 
-    async fn begin_async(&self, for_write: bool) -> DbResult<()> {
+    async fn begin_async(&mut self, for_write: bool) -> DbResult<()> {
         self.begin(for_write)
     }
 
-    fn commit_sync(&self) -> DbResult<()> {
+    fn commit_sync(&mut self) -> DbResult<()> {
         if self.session.borrow().in_transaction {
-            self.conn
-                .transaction_manager()
-                .commit_transaction(&self.conn)?;
+            <InternalConn as Connection>::TransactionManager::commit_transaction(
+                &mut *self.conn.write()?,
+            )?;
         }
         Ok(())
     }
 
-    fn rollback_sync(&self) -> DbResult<()> {
+    fn rollback_sync(&mut self) -> DbResult<()> {
         if self.session.borrow().in_transaction {
-            self.conn
-                .transaction_manager()
-                .rollback_transaction(&self.conn)?;
+            <InternalConn as Connection>::TransactionManager::rollback_transaction(
+                &mut *self.conn.write()?,
+            )?;
         }
         Ok(())
     }
 
-    fn erect_tombstone(&self, user_id: i32) -> DbResult<()> {
+    fn erect_tombstone(&mut self, user_id: i32) -> DbResult<()> {
         sql_query(format!(
             r#"INSERT INTO user_collections ({user_id}, {collection_id}, {modified})
                VALUES (?, ?, ?)
@@ -282,37 +283,40 @@ impl MysqlDb {
         .bind::<BigInt, _>(user_id as i64)
         .bind::<Integer, _>(TOMBSTONE)
         .bind::<BigInt, _>(self.timestamp().as_i64())
-        .execute(&self.conn)?;
+        .execute(&mut *self.conn.write()?)?;
         Ok(())
     }
 
-    fn delete_storage_sync(&self, user_id: UserIdentifier) -> DbResult<()> {
+    fn delete_storage_sync(&mut self, user_id: UserIdentifier) -> DbResult<()> {
         let user_id = user_id.legacy_id as i64;
         // Delete user data.
         delete(bso::table)
             .filter(bso::user_id.eq(user_id))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         // Delete user collections.
         delete(user_collections::table)
             .filter(user_collections::user_id.eq(user_id))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         Ok(())
     }
 
     // Deleting the collection should result in:
     //  - collection does not appear in /info/collections
     //  - X-Last-Modified timestamp at the storage level changing
-    fn delete_collection_sync(&self, params: params::DeleteCollection) -> DbResult<SyncTimestamp> {
+    fn delete_collection_sync(
+        &mut self,
+        params: params::DeleteCollection,
+    ) -> DbResult<SyncTimestamp> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         let mut count = delete(bso::table)
             .filter(bso::user_id.eq(user_id))
             .filter(bso::collection_id.eq(&collection_id))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         count += delete(user_collections::table)
             .filter(user_collections::user_id.eq(user_id))
             .filter(user_collections::collection_id.eq(&collection_id))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         if count == 0 {
             return Err(DbError::collection_not_found());
         } else {
@@ -321,21 +325,19 @@ impl MysqlDb {
         self.get_storage_timestamp_sync(params.user_id)
     }
 
-    pub(super) fn get_or_create_collection_id(&self, name: &str) -> DbResult<i32> {
+    pub(super) fn get_or_create_collection_id(&mut self, name: &str) -> DbResult<i32> {
         if let Some(id) = self.coll_cache.get_id(name)? {
             return Ok(id);
         }
 
-        let id = self.conn.transaction(|| {
-            diesel::insert_or_ignore_into(collections::table)
-                .values(collections::name.eq(name))
-                .execute(&self.conn)?;
+        diesel::insert_or_ignore_into(collections::table)
+            .values(collections::name.eq(name))
+            .execute(&mut *self.conn.write()?)?;
 
-            collections::table
-                .select(collections::id)
-                .filter(collections::name.eq(name))
-                .first(&self.conn)
-        })?;
+        let id = collections::table
+            .select(collections::id)
+            .filter(collections::name.eq(name))
+            .first(&mut *self.conn.write()?)?;
 
         if !self.session.borrow().in_write_transaction {
             self.coll_cache.put(id, name.to_owned())?;
@@ -344,7 +346,7 @@ impl MysqlDb {
         Ok(id)
     }
 
-    pub(super) fn get_collection_id(&self, name: &str) -> DbResult<i32> {
+    pub(super) fn get_collection_id(&mut self, name: &str) -> DbResult<i32> {
         if let Some(id) = self.coll_cache.get_id(name)? {
             return Ok(id);
         }
@@ -355,7 +357,7 @@ impl MysqlDb {
               WHERE name = ?",
         )
         .bind::<Text, _>(name)
-        .get_result::<IdResult>(&self.conn)
+        .get_result::<IdResult>(&mut *self.conn.write()?)
         .optional()?
         .ok_or_else(DbError::collection_not_found)?
         .id;
@@ -365,7 +367,7 @@ impl MysqlDb {
         Ok(id)
     }
 
-    fn _get_collection_name(&self, id: i32) -> DbResult<String> {
+    fn _get_collection_name(&mut self, id: i32) -> DbResult<String> {
         let name = if let Some(name) = self.coll_cache.get_name(id)? {
             name
         } else {
@@ -375,7 +377,7 @@ impl MysqlDb {
                   WHERE id = ?",
             )
             .bind::<Integer, _>(&id)
-            .get_result::<NameResult>(&self.conn)
+            .get_result::<NameResult>(&mut *self.conn.write()?)
             .optional()?
             .ok_or_else(DbError::collection_not_found)?
             .name
@@ -383,7 +385,7 @@ impl MysqlDb {
         Ok(name)
     }
 
-    fn put_bso_sync(&self, bso: params::PutBso) -> DbResult<results::PutBso> {
+    fn put_bso_sync(&mut self, bso: params::PutBso) -> DbResult<results::PutBso> {
         /*
         if bso.payload.is_none() && bso.sortindex.is_none() && bso.ttl.is_none() {
             // XXX: go returns an error here (ErrNothingToDo), and is treated
@@ -413,68 +415,72 @@ impl MysqlDb {
             }
         }
 
-        self.conn.transaction(|| {
-            let payload = bso.payload.as_deref().unwrap_or_default();
-            let sortindex = bso.sortindex;
-            let ttl = bso.ttl.map_or(DEFAULT_BSO_TTL, |ttl| ttl);
-            let q = format!(r#"
+        let payload = bso.payload.as_deref().unwrap_or_default();
+        let sortindex = bso.sortindex;
+        let ttl = bso.ttl.map_or(DEFAULT_BSO_TTL, |ttl| ttl);
+        let q = format!(
+            r#"
             INSERT INTO bso ({user_id}, {collection_id}, id, sortindex, payload, {modified}, {expiry})
             VALUES (?, ?, ?, ?, ?, ?, ?)
                 ON DUPLICATE KEY UPDATE
                    {user_id} = VALUES({user_id}),
                    {collection_id} = VALUES({collection_id}),
                    id = VALUES(id)
-            "#, user_id=USER_ID, modified=MODIFIED, collection_id=COLLECTION_ID, expiry=EXPIRY);
-            let q = format!(
-                "{}{}",
-                q,
-                if bso.sortindex.is_some() {
-                    ", sortindex = VALUES(sortindex)"
-                } else {
-                    ""
-                },
-            );
-            let q = format!(
-                "{}{}",
-                q,
-                if bso.payload.is_some() {
-                    ", payload = VALUES(payload)"
-                } else {
-                    ""
-                },
-            );
-            let q = format!(
-                "{}{}",
-                q,
-                if bso.ttl.is_some() {
-                    format!(", {expiry} = VALUES({expiry})", expiry=EXPIRY)
-                } else {
-                    "".to_owned()
-                },
-            );
-            let q = format!(
-                "{}{}",
-                q,
-                if bso.payload.is_some() || bso.sortindex.is_some() {
-                    format!(", {modified} = VALUES({modified})", modified=MODIFIED)
-                } else {
-                    "".to_owned()
-                },
-            );
-            sql_query(q)
-                .bind::<BigInt, _>(user_id as i64) // XXX:
-                .bind::<Integer, _>(&collection_id)
-                .bind::<Text, _>(&bso.id)
-                .bind::<Nullable<Integer>, _>(sortindex)
-                .bind::<Text, _>(payload)
-                .bind::<BigInt, _>(timestamp)
-                .bind::<BigInt, _>(timestamp + (i64::from(ttl) * 1000)) // remember: this is in millis
-                .execute(&self.conn)?;
-            self.update_collection(user_id as u32, collection_id)
-        })
+            "#,
+            user_id = USER_ID,
+            modified = MODIFIED,
+            collection_id = COLLECTION_ID,
+            expiry = EXPIRY
+        );
+        let q = format!(
+            "{}{}",
+            q,
+            if bso.sortindex.is_some() {
+                ", sortindex = VALUES(sortindex)"
+            } else {
+                ""
+            },
+        );
+        let q = format!(
+            "{}{}",
+            q,
+            if bso.payload.is_some() {
+                ", payload = VALUES(payload)"
+            } else {
+                ""
+            },
+        );
+        let q = format!(
+            "{}{}",
+            q,
+            if bso.ttl.is_some() {
+                format!(", {expiry} = VALUES({expiry})", expiry = EXPIRY)
+            } else {
+                "".to_owned()
+            },
+        );
+        let q = format!(
+            "{}{}",
+            q,
+            if bso.payload.is_some() || bso.sortindex.is_some() {
+                format!(", {modified} = VALUES({modified})", modified = MODIFIED)
+            } else {
+                "".to_owned()
+            },
+        );
+        sql_query(q)
+            .bind::<BigInt, _>(user_id as i64) // XXX:
+            .bind::<Integer, _>(&collection_id)
+            .bind::<Text, _>(&bso.id)
+            .bind::<Nullable<Integer>, _>(sortindex)
+            .bind::<Text, _>(payload)
+            .bind::<BigInt, _>(timestamp)
+            .bind::<BigInt, _>(timestamp + (i64::from(ttl) * 1000)) // remember: this is in millis
+            .execute(&mut *self.conn.write()?)?;
+        self.update_collection(user_id as u32, collection_id)
     }
 
-    fn get_bsos_sync(&self, params: params::GetBsos) -> DbResult<results::GetBsos> {
+    fn get_bsos_sync(&mut self, params: params::GetBsos) -> DbResult<results::GetBsos> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         let now = self.timestamp().as_i64();
@@ -537,7 +543,7 @@ impl MysqlDb {
             // https://github.com/mozilla-services/server-syncstorage/blob/a0f8117/syncstorage/storage/sql/__init__.py#L404
             query = query.offset(numeric_offset);
         }
-        let mut bsos = query.load::<results::GetBso>(&self.conn)?;
+        let mut bsos = query.load::<results::GetBso>(&mut *self.conn.write()?)?;
 
         // XXX: an additional get_collection_timestamp is done here in
         // python to trigger potential CollectionNotFoundErrors
@@ -564,7 +570,7 @@ impl MysqlDb {
         })
     }
 
-    fn get_bso_ids_sync(&self, params: params::GetBsos) -> DbResult<results::GetBsoIds> {
+    fn get_bso_ids_sync(&mut self, params: params::GetBsos) -> DbResult<results::GetBsoIds> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         let mut query = bso::table
@@ -607,7 +613,7 @@ impl MysqlDb {
             // https://github.com/mozilla-services/server-syncstorage/blob/a0f8117/syncstorage/storage/sql/__init__.py#L404
             query = query.offset(numeric_offset);
         }
-        let mut ids = query.load::<String>(&self.conn)?;
+        let mut ids = query.load::<String>(&mut *self.conn.write()?)?;
 
         // XXX: an additional get_collection_timestamp is done here in
         // python to trigger potential CollectionNotFoundErrors
@@ -627,7 +633,7 @@ impl MysqlDb {
         })
     }
 
-    fn get_bso_sync(&self, params: params::GetBso) -> DbResult<Option<results::GetBso>> {
+    fn get_bso_sync(&mut self, params: params::GetBso) -> DbResult<Option<results::GetBso>> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         Ok(bso::table
@@ -642,11 +648,11 @@ impl MysqlDb {
             .filter(bso::collection_id.eq(&collection_id))
             .filter(bso::id.eq(&params.id))
             .filter(bso::expiry.ge(self.timestamp().as_i64()))
-            .get_result::<results::GetBso>(&self.conn)
+            .get_result::<results::GetBso>(&mut *self.conn.write()?)
             .optional()?)
     }
 
-    fn delete_bso_sync(&self, params: params::DeleteBso) -> DbResult<results::DeleteBso> {
+    fn delete_bso_sync(&mut self, params: params::DeleteBso) -> DbResult<results::DeleteBso> {
         let user_id = params.user_id.legacy_id;
         let collection_id = self.get_collection_id(&params.collection)?;
         let affected_rows = delete(bso::table)
@@ -654,25 +660,25 @@ impl MysqlDb {
             .filter(bso::collection_id.eq(&collection_id))
             .filter(bso::id.eq(params.id))
             .filter(bso::expiry.gt(&self.timestamp().as_i64()))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         if affected_rows == 0 {
             return Err(DbError::bso_not_found());
         }
         self.update_collection(user_id as u32, collection_id)
     }
 
-    fn delete_bsos_sync(&self, params: params::DeleteBsos) -> DbResult<results::DeleteBsos> {
+    fn delete_bsos_sync(&mut self, params: params::DeleteBsos) -> DbResult<results::DeleteBsos> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         delete(bso::table)
             .filter(bso::user_id.eq(user_id))
             .filter(bso::collection_id.eq(&collection_id))
             .filter(bso::id.eq_any(params.ids))
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         self.update_collection(user_id as u32, collection_id)
     }
 
-    fn post_bsos_sync(&self, input: params::PostBsos) -> DbResult<results::PostBsos> {
+    fn post_bsos_sync(&mut self, input: params::PostBsos) -> DbResult<results::PostBsos> {
         let collection_id = self.get_or_create_collection_id(&input.collection)?;
         let mut result = results::PostBsos {
             modified: self.timestamp(),
@@ -705,18 +711,18 @@ impl MysqlDb {
         Ok(result)
     }
 
-    fn get_storage_timestamp_sync(&self, user_id: UserIdentifier) -> DbResult<SyncTimestamp> {
+    fn get_storage_timestamp_sync(&mut self, user_id: UserIdentifier) -> DbResult<SyncTimestamp> {
         let user_id = user_id.legacy_id as i64;
         let modified = user_collections::table
             .select(max(user_collections::modified))
             .filter(user_collections::user_id.eq(user_id))
-            .first::<Option<i64>>(&self.conn)?
+            .first::<Option<i64>>(&mut *self.conn.write()?)?
             .unwrap_or_default();
         SyncTimestamp::from_i64(modified).map_err(Into::into)
     }
 
     fn get_collection_timestamp_sync(
-        &self,
+        &mut self,
         params: params::GetCollectionTimestamp,
     ) -> DbResult<SyncTimestamp> {
         let user_id = params.user_id.legacy_id as u32;
@@ -733,12 +739,15 @@ impl MysqlDb {
             .select(user_collections::modified)
             .filter(user_collections::user_id.eq(user_id as i64))
             .filter(user_collections::collection_id.eq(collection_id))
-            .first(&self.conn)
+            .first(&mut *self.conn.write()?)
             .optional()?
             .ok_or_else(DbError::collection_not_found)
     }
 
-    fn get_bso_timestamp_sync(&self, params: params::GetBsoTimestamp) -> DbResult<SyncTimestamp> {
+    fn get_bso_timestamp_sync(
+        &mut self,
+        params: params::GetBsoTimestamp,
+    ) -> DbResult<SyncTimestamp> {
         let user_id = params.user_id.legacy_id as i64;
         let collection_id = self.get_collection_id(&params.collection)?;
         let modified = bso::table
@@ -746,14 +755,14 @@ impl MysqlDb {
             .filter(bso::user_id.eq(user_id))
             .filter(bso::collection_id.eq(&collection_id))
             .filter(bso::id.eq(&params.id))
-            .first::<i64>(&self.conn)
+            .first::<i64>(&mut *self.conn.write()?)
             .optional()?
             .unwrap_or_default();
         SyncTimestamp::from_i64(modified).map_err(Into::into)
     }
 
     fn get_collection_timestamps_sync(
-        &self,
+        &mut self,
         user_id: UserIdentifier,
     ) -> DbResult<results::GetCollectionTimestamps> {
         let modifieds = sql_query(format!(
@@ -767,7 +776,7 @@ impl MysqlDb {
         ))
         .bind::<BigInt, _>(user_id.legacy_id as i64)
         .bind::<Integer, _>(TOMBSTONE)
-        .load::<UserCollectionsResult>(&self.conn)?
+        .load::<UserCollectionsResult>(&mut *self.conn.write()?)?
         .into_iter()
         .map(|cr| {
             SyncTimestamp::from_i64(cr.last_modified)
@@ -778,13 +787,12 @@ impl MysqlDb {
         self.map_collection_names(modifieds)
     }
 
-    fn check_sync(&self) -> DbResult<results::Check> {
-        // has the database been up for more than 0 seconds?
-        let result = sql_query("SHOW STATUS LIKE \"Uptime\"").execute(&self.conn)?;
-        Ok(result as u64 > 0)
+    fn check_sync(&mut self) -> DbResult<results::Check> {
+        diesel::sql_query("SELECT 1").execute(&mut *self.conn.write()?)?;
+        Ok(true)
     }
 
-    fn map_collection_names<T>(&self, by_id: HashMap<i32, T>) -> DbResult<HashMap<String, T>> {
+    fn map_collection_names<T>(&mut self, by_id: HashMap<i32, T>) -> DbResult<HashMap<String, T>> {
         let mut names = self.load_collection_names(by_id.keys())?;
         by_id
             .into_iter()
@@ -797,7 +805,7 @@ impl MysqlDb {
     }
 
     fn load_collection_names<'a>(
-        &self,
+        &mut self,
         collection_ids: impl Iterator<Item = &'a i32>,
     ) -> DbResult<HashMap<i32, String>> {
         let mut names = HashMap::new();
@@ -814,7 +822,7 @@ impl MysqlDb {
             let result = collections::table
                 .select((collections::id, collections::name))
                 .filter(collections::id.eq_any(uncached))
-                .load::<(i32, String)>(&self.conn)?;
+                .load::<(i32, String)>(&mut *self.conn.write()?)?;
 
             for (id, name) in result {
                 names.insert(id, name.clone());
@@ -828,7 +836,7 @@ impl MysqlDb {
     }
 
     pub(super) fn update_collection(
-        &self,
+        &mut self,
         user_id: u32,
         collection_id: i32,
     ) -> DbResult<SyncTimestamp> {
@@ -856,22 +864,23 @@ impl MysqlDb {
             total_bytes = TOTAL_BYTES,
         );
         let total_bytes = quota.total_bytes as i64;
+        let timestamp = self.timestamp().as_i64();
         sql_query(upsert)
             .bind::<BigInt, _>(user_id as i64)
             .bind::<Integer, _>(&collection_id)
-            .bind::<BigInt, _>(&self.timestamp().as_i64())
+            .bind::<BigInt, _>(&timestamp)
             .bind::<BigInt, _>(&total_bytes)
             .bind::<Integer, _>(&quota.count)
-            .bind::<BigInt, _>(&self.timestamp().as_i64())
+            .bind::<BigInt, _>(&timestamp)
             .bind::<BigInt, _>(&total_bytes)
             .bind::<Integer, _>(&quota.count)
-            .execute(&self.conn)?;
+            .execute(&mut *self.conn.write()?)?;
         Ok(self.timestamp())
     }
 
     // Perform a lighter weight "read only" storage size check
     fn get_storage_usage_sync(
-        &self,
+        &mut self,
         user_id: UserIdentifier,
     ) -> DbResult<results::GetStorageUsage> {
         let uid = user_id.legacy_id as i64;
@@ -879,13 +888,13 @@ impl MysqlDb {
             .select(sql::<Nullable<BigInt>>("SUM(LENGTH(payload))"))
             .filter(bso::user_id.eq(uid))
             .filter(bso::expiry.gt(&self.timestamp().as_i64()))
-            .get_result::<Option<i64>>(&self.conn)?;
+            .get_result::<Option<i64>>(&mut *self.conn.write()?)?;
         Ok(total_bytes.unwrap_or_default() as u64)
     }
 
     // Perform a lighter weight "read only" quota storage check
     fn get_quota_usage_sync(
-        &self,
+        &mut self,
         params: params::GetQuotaUsage,
     ) -> DbResult<results::GetQuotaUsage> {
         let uid = params.user_id.legacy_id as i64;
@@ -896,7 +905,7 @@ impl MysqlDb {
             ))
             .filter(user_collections::user_id.eq(uid))
             .filter(user_collections::collection_id.eq(params.collection_id))
-            .get_result(&self.conn)
+            .get_result(&mut *self.conn.write()?)
             .optional()?
             .unwrap_or_default();
         Ok(results::GetQuotaUsage {
@@ -907,7 +916,7 @@ impl MysqlDb {
 
     // perform a heavier weight quota calculation
     fn calc_quota_usage_sync(
-        &self,
+        &mut self,
         user_id: u32,
         collection_id: i32,
     ) -> DbResult<results::GetQuotaUsage> {
@@ -919,7 +928,7 @@ impl MysqlDb {
             .filter(bso::user_id.eq(user_id as i64))
             .filter(bso::expiry.gt(self.timestamp().as_i64()))
             .filter(bso::collection_id.eq(collection_id))
-            .get_result(&self.conn)
+            .get_result(&mut *self.conn.write()?)
             .optional()?
             .unwrap_or_default();
         Ok(results::GetQuotaUsage {
@@ -929,7 +938,7 @@ impl MysqlDb {
     }
 
     fn get_collection_usage_sync(
-        &self,
+        &mut self,
         user_id: UserIdentifier,
     ) -> DbResult<results::GetCollectionUsage> {
         let counts = bso::table
@@ -937,14 +946,14 @@ impl MysqlDb {
             .filter(bso::user_id.eq(user_id.legacy_id as i64))
             .filter(bso::expiry.gt(&self.timestamp().as_i64()))
             .group_by(bso::collection_id)
-            .load(&self.conn)?
+            .load(&mut *self.conn.write()?)?
             .into_iter()
             .collect();
         self.map_collection_names(counts)
     }
 
     fn get_collection_counts_sync(
-        &self,
+        &mut self,
         user_id: UserIdentifier,
     ) -> DbResult<results::GetCollectionCounts> {
         let counts = bso::table
@@ -958,7 +967,7 @@ impl MysqlDb {
             .filter(bso::user_id.eq(user_id.legacy_id as i64))
             .filter(bso::expiry.gt(&self.timestamp().as_i64()))
             .group_by(bso::collection_id)
-            .load(&self.conn)?
+            .load(&mut *self.conn.write()?)?
             .into_iter()
             .collect();
         self.map_collection_names(counts)
@@ -970,7 +979,7 @@ impl MysqlDb {
     batch_db_method!(commit_batch_sync, commit, CommitBatch);
     batch_db_method!(delete_batch_sync, delete, DeleteBatch);
 
-    fn get_batch_sync(&self, params: params::GetBatch) -> DbResult<Option<results::GetBatch>> {
+    fn get_batch_sync(&mut self, params: params::GetBatch) -> DbResult<Option<results::GetBatch>> {
         batch::get(self, params)
     }
 
@@ -982,23 +991,23 @@ impl MysqlDb {
 impl Db for MysqlDb {
     type Error = DbError;
 
-    fn commit(&self) -> DbFuture<'_, (), Self::Error> {
-        let db = self.clone();
+    fn commit(&mut self) -> DbFuture<'_, (), Self::Error> {
+        let mut db = self.clone();
         Box::pin(self.blocking_threadpool.spawn(move || db.commit_sync()))
     }
 
-    fn rollback(&self) -> DbFuture<'_, (), Self::Error> {
-        let db = self.clone();
+    fn rollback(&mut self) -> DbFuture<'_, (), Self::Error> {
+        let mut db = self.clone();
         Box::pin(self.blocking_threadpool.spawn(move || db.rollback_sync()))
     }
 
-    fn begin(&self, for_write: bool) -> DbFuture<'_, (), Self::Error> {
-        let db = self.clone();
+    fn begin(&mut self, for_write: bool) -> DbFuture<'_, (), Self::Error> {
+        let mut db = self.clone();
         Box::pin(async move { db.begin_async(for_write).map_err(Into::into).await })
     }
 
-    fn check(&self) -> DbFuture<'_, results::Check, Self::Error> {
-        let db = self.clone();
+    fn check(&mut self) -> DbFuture<'_, results::Check, Self::Error> {
+        let mut db = self.clone();
         Box::pin(self.blocking_threadpool.spawn(move || db.check_sync()))
     }
 
@@ -1057,8 +1066,8 @@ impl Db for MysqlDb {
     );
     sync_db_method!(commit_batch, commit_batch_sync, CommitBatch);
 
-    fn get_collection_id(&self, name: String) -> DbFuture<'_, i32, Self::Error> {
-        let db = self.clone();
+    fn get_collection_id(&mut self, name: String) -> DbFuture<'_, i32, Self::Error> {
+        let mut db = self.clone();
         Box::pin(
             self.blocking_threadpool
                 .spawn(move || db.get_collection_id(&name)),
@@ -1069,8 +1078,8 @@ impl Db for MysqlDb {
         results::ConnectionInfo::default()
     }
 
-    fn create_collection(&self, name: String) -> DbFuture<'_, i32, Self::Error> {
-        let db = self.clone();
+    fn create_collection(&mut self, name: String) -> DbFuture<'_, i32, Self::Error> {
+        let mut db = self.clone();
         Box::pin(
             self.blocking_threadpool
                 .spawn(move || db.get_or_create_collection_id(&name)),
@@ -1078,10 +1087,10 @@ impl Db for MysqlDb {
     }
 
     fn update_collection(
-        &self,
+        &mut self,
         param: params::UpdateCollection,
     ) -> DbFuture<'_, SyncTimestamp, Self::Error> {
-        let db = self.clone();
+        let mut db = self.clone();
         Box::pin(self.blocking_threadpool.spawn(move || {
             db.update_collection(param.user_id.legacy_id as u32, param.collection_id)
         }))
@@ -1091,13 +1100,13 @@ impl Db for MysqlDb {
         self.timestamp()
     }
 
-    fn set_timestamp(&self, timestamp: SyncTimestamp) {
+    fn set_timestamp(&mut self, timestamp: SyncTimestamp) {
         self.session.borrow_mut().timestamp = timestamp;
     }
 
     sync_db_method!(delete_batch, delete_batch_sync, DeleteBatch);
 
-    fn clear_coll_cache(&self) -> DbFuture<'_, (), Self::Error> {
+    fn clear_coll_cache(&mut self) -> DbFuture<'_, (), Self::Error> {
         let db = self.clone();
         Box::pin(self.blocking_threadpool.spawn(move || {
             db.coll_cache.clear();
@@ -1112,30 +1121,26 @@ impl Db for MysqlDb {
             enforced,
         }
     }
-
-    fn box_clone(&self) -> Box<dyn Db<Error = Self::Error>> {
-        Box::new(self.clone())
-    }
 }
 
 #[derive(Debug, QueryableByName)]
 struct IdResult {
-    #[sql_type = "Integer"]
+    #[diesel(sql_type = Integer)]
     id: i32,
 }
 
 #[allow(dead_code)] // Not really dead, Rust can't see the use above
 #[derive(Debug, QueryableByName)]
 struct NameResult {
-    #[sql_type = "Text"]
+    #[diesel(sql_type = Text)]
     name: String,
 }
 
 #[derive(Debug, QueryableByName)]
 struct UserCollectionsResult {
     // Can't substitute column names here.
-    #[sql_type = "Integer"]
+    #[diesel(sql_type = Integer)]
     collection: i32, // COLLECTION_ID
-    #[sql_type = "BigInt"]
+    #[diesel(sql_type = BigInt)]
     last_modified: i64, // LAST_MODIFIED
 }
