@@ -76,7 +76,7 @@ impl SpannerDbPool {
         let conn = self.pool.get().await.map_err(|e| match e {
             deadpool::managed::PoolError::Backend(dbe) => dbe,
             deadpool::managed::PoolError::Timeout(timeout_type) => {
-                DbError::internal(format!("deadpool Timeout: {:?}", timeout_type))
+                DbError::pool_timeout(timeout_type)
             }
             _ => DbError::internal(format!("deadpool PoolError: {}", e)),
         })?;
