@@ -7,7 +7,6 @@ use syncserver_db_common::error::SqlError;
 use thiserror::Error;
 use tokenserver_common::TokenserverError;
 
-pub(crate) type DbFuture<'a, T> = syncserver_db_common::DbFuture<'a, T, DbError>;
 pub(crate) type DbResult<T> = Result<T, DbError>;
 
 /// An error type that represents any database-related errors that may occur while processing a
@@ -23,6 +22,10 @@ impl DbError {
     pub(crate) fn internal(msg: String) -> Self {
         DbErrorKind::Internal(msg).into()
     }
+
+    pub(crate) fn pool_timeout(timeout_type: deadpool::managed::TimeoutType) -> Self {
+        DbErrorKind::PoolTimeout(timeout_type).into()
+    }
 }
 
 impl ReportableError for DbError {
@@ -36,6 +39,7 @@ impl ReportableError for DbError {
     fn is_sentry_event(&self) -> bool {
         match &self.kind {
             DbErrorKind::Sql(e) => e.is_sentry_event(),
+            DbErrorKind::PoolTimeout(_) => false,
             _ => true,
         }
     }
@@ -43,6 +47,7 @@ impl ReportableError for DbError {
     fn metric_label(&self) -> Option<&str> {
         match &self.kind {
             DbErrorKind::Sql(e) => e.metric_label(),
+            DbErrorKind::PoolTimeout(_) => Some("storage.pool.timeout"),
             _ => None,
         }
     }
@@ -55,6 +60,9 @@ enum DbErrorKind {
 
     #[error("Unexpected error: {}", _0)]
     Internal(String),
+
+    #[error("A database pool timeout occurred, type: {:?}", _0)]
+    PoolTimeout(deadpool::managed::TimeoutType),
 }
 
 impl From<DbErrorKind> for DbError {
@@ -65,7 +73,7 @@ impl From<DbErrorKind> for DbError {
                 backtrace: Box::new(mysql_error.backtrace.clone()),
                 kind,
             },
-            DbErrorKind::Internal(_) => Self {
+            _ => Self {
                 kind,
                 status: StatusCode::INTERNAL_SERVER_ERROR,
                 backtrace: Box::new(Backtrace::new()),
@@ -118,9 +126,14 @@ from_error!(
     |error: diesel::r2d2::PoolError| DbError::from(DbErrorKind::Sql(SqlError::from(error)))
 );
 from_error!(
-    diesel_migrations::RunMigrationsError,
+    diesel_migrations::MigrationError,
     DbError,
-    |error: diesel_migrations::RunMigrationsError| DbError::from(DbErrorKind::Sql(SqlError::from(
+    |error: diesel_migrations::MigrationError| DbError::from(DbErrorKind::Sql(SqlError::from(
         error
     )))
 );
+from_error!(
+    std::boxed::Box<dyn std::error::Error + std::marker::Send + Sync>,
+    DbError,
+    |error: std::boxed::Box<dyn std::error::Error>| DbError::internal_error(error.to_string())
+);
